@@ -3,6 +3,7 @@ import logging
 import click
 import yaml
 from pkg_resources import get_distribution
+from rich.logging import RichHandler
 
 from scanapi.exit_code import ExitCode
 from scanapi.scan import scan
@@ -16,10 +17,7 @@ dist = get_distribution("scanapi")
 @click.group()
 @click.version_option(version=dist.version)
 def main():
-    """
-    Automated Testing and Documentation for your REST API.
-    """
-    pass
+    """Automated Testing and Documentation for your REST API."""
 
 
 @main.command(context_settings=CONTEXT_SETTINGS)
@@ -38,6 +36,13 @@ def main():
     is_flag=True,
     help="Run ScanAPI without generating report.",
 )
+@click.option(
+    "-b",
+    "--browser",
+    "open_browser",
+    is_flag=True,
+    help="Open the results file using a browser",
+)
 @click.option(
     "-c",
     "--config-path",
@@ -60,12 +65,29 @@ def main():
     default="INFO",
     help="Set the debug logging level for the program.",
 )
-def run(spec_path, output_path, no_report, config_path, template, log_level):
+def run(
+    spec_path,
+    output_path,
+    no_report,
+    config_path,
+    template,
+    log_level,
+    open_browser,
+):
     """
     Automated Testing and Documentation for your REST API.
     SPEC_PATH argument is the API specification file path.
     """
-    logging.basicConfig(level=log_level, format="%(message)s")
+    logging.basicConfig(
+        level=log_level,
+        format="%(message)s",
+        datefmt="[%X]",
+        handlers=[
+            RichHandler(
+                show_time=False, markup=True, show_path=(log_level == "DEBUG")
+            )
+        ],
+    )
     logger = logging.getLogger(__name__)
 
     click_preferences = {
@@ -74,6 +96,7 @@ def run(spec_path, output_path, no_report, config_path, template, log_level):
         "no_report": no_report,
         "config_path": config_path,
         "template": template,
+        "open_browser": open_browser,
     }
 
     try:
