@@ -1,6 +1,4 @@
-"""
-Code based on solution https://gist.github.com/joshbode/569627ced3076931b02f
-"""
+"""Code Reference https://gist.github.com/joshbode/569627ced3076931b02f"""
 
 import logging
 import os
@@ -8,7 +6,7 @@ from typing import IO, Any
 
 import yaml
 
-from scanapi.errors import EmptyConfigFileError
+from scanapi.errors import BadConfigIncludeError, EmptyConfigFileError
 
 logger = logging.getLogger(__name__)
 
@@ -28,10 +26,15 @@ class Loader(yaml.SafeLoader):
 
 def construct_include(loader: Loader, node: yaml.Node) -> Any:
     """Include file referenced at node."""
-    relative_path = os.path.join(loader.root, loader.construct_scalar(node))
+    if not isinstance(node, yaml.ScalarNode):
+        include_node_str = yaml.serialize(node).strip()
+        message = f"Include tag value is not a scalar: {include_node_str}"
+        raise BadConfigIncludeError(message)
+    include_file_path = str(loader.construct_scalar(node))
+    relative_path = os.path.join(loader.root, include_file_path)
     full_path = os.path.abspath(relative_path)
 
-    with open(full_path, "r") as f:
+    with open(full_path) as f:
         return yaml.load(f, Loader)
 
 
@@ -41,7 +44,10 @@ def load_config_file(file_path):
     returns it.
     """
     with open(file_path, "r") as stream:
-        logger.info(f"Loading file {file_path}")
+        logger.info(
+            f"Loading file [deep_sky_blue1 underline]{file_path}",
+            extra={"highlighter": None},
+        )
         data = yaml.load(stream, Loader)
 
         if not data:
