@@ -1,21 +1,30 @@
 class MalformedSpecError(Exception):
-    pass
+    """Raised when API spec is invalid;
+
+    base class for other exceptions
+    """
 
 
 class HTTPMethodNotAllowedError(MalformedSpecError):
     """Raised when the HTTP method in the API spec is invalid"""
 
     def __init__(self, method, allowed_methods, *args):
-        message = f"HTTP method not supported: {method}. Supported methods: {allowed_methods}."
-        super(HTTPMethodNotAllowedError, self).__init__(message, *args)
+        message = (
+            f"HTTP method not supported: {method}. "
+            f"Supported methods: {allowed_methods}."
+        )
+        super().__init__(message, *args)
 
 
 class InvalidKeyError(MalformedSpecError):
     """Raised when an invalid key is specified in the API spec"""
 
     def __init__(self, key, scope, available_keys, *args):
-        message = f"Invalid key '{key}' at '{scope}' scope. Available keys are: {available_keys}"
-        super(InvalidKeyError, self).__init__(message, *args)
+        message = (
+            f"Invalid key '{key}' at '{scope}' scope. "
+            f"Available keys are: {available_keys}"
+        )
+        super().__init__(message, *args)
 
 
 class MissingMandatoryKeyError(MalformedSpecError):
@@ -24,7 +33,7 @@ class MissingMandatoryKeyError(MalformedSpecError):
     def __init__(self, missing_keys, scope, *args):
         missing_keys_str = ", ".join(f"'{k}'" for k in sorted(missing_keys))
         message = f"Missing {missing_keys_str} key(s) at '{scope}' scope"
-        super(MissingMandatoryKeyError, self).__init__(message, *args)
+        super().__init__(message, *args)
 
 
 class InvalidPythonCodeError(MalformedSpecError):
@@ -36,14 +45,14 @@ class InvalidPythonCodeError(MalformedSpecError):
             f"Exception: {error_message}. "
             f"Code: {code}."
         )
-        super(InvalidPythonCodeError, self).__init__(error_message, *args)
+        super().__init__(error_message, *args)
 
 
 class BadConfigurationError(Exception):
-    """Raised when an environment variable was not set or was badly configured"""
+    """Raised when an environment variable was not set or badly configured."""
 
     def __init__(self, env_var, *args):
-        super(BadConfigurationError, self).__init__(
+        super().__init__(
             f"{env_var} environment variable not set or badly configured",
             *args,
         )
@@ -54,4 +63,8 @@ class EmptyConfigFileError(Exception):
 
     def __init__(self, file_path, *args):
         message = f"File '{file_path}' is empty."
-        super(EmptyConfigFileError, self).__init__(message, *args)
+        super().__init__(message, *args)
+
+
+class BadConfigIncludeError(Exception):
+    """Raised when the value of the !include yaml tag is not a scalar."""
